@@ -11,6 +11,17 @@ def create_project_name(num, client, name):
     return f"{num}_{client.upper()}_{name.upper()}"
 
 
+def get_int_from_user(question):
+    while True:
+        try:
+            intval = int(input(question))
+        except ValueError:
+            print("Sorry, I didn't understand that? Did you type a number?")
+            continue
+        else:
+            return intval
+
+
 def clearConsole():
     return os.system("cls" if os.name in ("nt", "dos") else "clear")
 
@@ -24,12 +35,12 @@ def get_ftrack_session():
 
 
 def select_artist(team, users, question):
-    ia, index = pick([u["username"] for u in team], question, indicator="👉")
-    return [i for i in users if ia.lower() in i["username"].lower()][0]
+    ia = pick([u["username"] for u in team], question, indicator="👉")
+    return [i for i in users if ia[0].lower() in i["username"].lower()][0]
 
 
 def number_to_letter(input: int) -> str:
-    return str(chr(ord('@') + input + 1))
+    return str(chr(ord("@") + input + 1))
 
 
 def shotnumber_to_letter(input: int) -> str:
