@@ -102,15 +102,6 @@ def create_new_project(session):
 
     project_name = create_project_name(num, client, projname)
 
-    while True:
-        try:
-            num_int = int(input("Enter amount of INT shots:\n"))
-        except ValueError:
-            print("Sorry, I didn't understand that? Did you type a number?")
-            continue
-        else:
-            print(f"Number of INT:{num_int}")
-            break
     num_int = get_int_from_user("Enter amount of INT shots: ")
     num_ext = get_int_from_user("Enter amount of EXT shots: ")
 
